=== modified file 'cmd/juju/addunit.go'
--- cmd/juju/addunit.go	2012-09-03 14:07:19 +0000
+++ cmd/juju/addunit.go	2012-09-03 17:35:44 +0000
@@ -44,7 +44,7 @@
 // Run connects to the environment specified on the command line 
 // and calls conn.AddUnits.
 func (c *AddUnitCommand) Run(_ *cmd.Context) error {
-	conn, err := juju.NewConn(c.EnvName)
+	conn, err := juju.NewConnFromName(c.EnvName)
 	if err != nil {
 		return err
 	}

=== modified file 'cmd/juju/deploy.go'
--- cmd/juju/deploy.go	2012-07-25 11:14:19 +0000
+++ cmd/juju/deploy.go	2012-09-03 17:35:44 +0000
@@ -77,7 +77,7 @@
 }
 
 func (c *DeployCommand) Run(ctx *cmd.Context) error {
-	conn, err := juju.NewConn(c.EnvName)
+	conn, err := juju.NewConnFromName(c.EnvName)
 	if err != nil {
 		return err
 	}

=== modified file 'cmd/juju/expose.go'
--- cmd/juju/expose.go	2012-09-03 14:07:19 +0000
+++ cmd/juju/expose.go	2012-09-03 17:35:44 +0000
@@ -34,7 +34,7 @@
 // Run changes the juju-managed firewall to expose any
 // ports that were also explicitly marked by units as open.
 func (c *ExposeCommand) Run(_ *cmd.Context) error {
-	conn, err := juju.NewConn(c.EnvName)
+	conn, err := juju.NewConnFromName(c.EnvName)
 	if err != nil {
 		return err
 	}

=== modified file 'cmd/juju/status.go'
--- cmd/juju/status.go	2012-09-03 14:07:19 +0000
+++ cmd/juju/status.go	2012-09-03 17:35:44 +0000
@@ -37,7 +37,7 @@
 }
 
 func (c *StatusCommand) Run(ctx *cmd.Context) error {
-	conn, err := juju.NewConn(c.EnvName)
+	conn, err := juju.NewConnFromName(c.EnvName)
 	if err != nil {
 		return err
 	}

=== modified file 'cmd/juju/unexpose.go'
--- cmd/juju/unexpose.go	2012-09-03 14:07:19 +0000
+++ cmd/juju/unexpose.go	2012-09-03 17:35:44 +0000
@@ -34,7 +34,7 @@
 // Run changes the juju-managed firewall to hide any
 // ports that were also explicitly marked by units as closed.
 func (c *UnexposeCommand) Run(_ *cmd.Context) error {
-	conn, err := juju.NewConn(c.EnvName)
+	conn, err := juju.NewConnFromName(c.EnvName)
 	if err != nil {
 		return err
 	}

=== modified file 'environs/jujutest/livetests.go'
--- environs/jujutest/livetests.go	2012-09-03 16:29:38 +0000
+++ environs/jujutest/livetests.go	2012-09-03 17:35:44 +0000
@@ -157,7 +157,7 @@
 	}
 	t.BootstrapOnce(c)
 
-	conn, err := juju.NewConnFromEnviron(t.Env)
+	conn, err := juju.NewConn(t.Env)
 	c.Assert(err, IsNil)
 	defer conn.Close()
 

=== modified file 'juju/conn.go'
--- juju/conn.go	2012-09-03 16:29:38 +0000
+++ juju/conn.go	2012-09-03 17:35:44 +0000
@@ -19,10 +19,10 @@
 	State   *state.State
 }
 
-// NewConnFromEnviron returns a new Conn that uses the
+// NewConn returns a new Conn that uses the
 // given environment. The environment must have already
 // been bootstrapped.
-func NewConnFromEnviron(environ environs.Environ) (*Conn, error) {
+func NewConn(environ environs.Environ) (*Conn, error) {
 	info, err := environ.StateInfo()
 	if err != nil {
 		return nil, err
@@ -46,14 +46,14 @@
 	}, nil
 }
 
-// NewConn returns a Conn pointing at the environName environment, or the
+// NewConnFromName returns a Conn pointing at the environName environment, or the
 // default environment if not specified.
-func NewConn(environName string) (*Conn, error) {
+func NewConnFromName(environName string) (*Conn, error) {
 	environ, err := environs.NewFromName(environName)
 	if err != nil {
 		return nil, err
 	}
-	return NewConnFromEnviron(environ)
+	return NewConn(environ)
 }
 
 // Close terminates the connection to the environment and releases

=== modified file 'juju/conn_test.go'
--- juju/conn_test.go	2012-09-03 16:29:38 +0000
+++ juju/conn_test.go	2012-09-03 17:35:44 +0000
@@ -28,11 +28,11 @@
 	cs.LoggingSuite.TearDownTest(c)
 }
 
-func (*ConnSuite) TestNewConn(c *C) {
+func (*ConnSuite) TestNewConnFromName(c *C) {
 	home := c.MkDir()
 	defer os.Setenv("HOME", os.Getenv("HOME"))
 	os.Setenv("HOME", home)
-	conn, err := juju.NewConn("")
+	conn, err := juju.NewConnFromName("")
 	c.Assert(conn, IsNil)
 	c.Assert(err, ErrorMatches, ".*: no such file or directory")
 
@@ -57,7 +57,7 @@
 
 	// Just run through a few operations on the dummy provider and verify that
 	// they behave as expected.
-	conn, err = juju.NewConn("")
+	conn, err = juju.NewConnFromName("")
 	c.Assert(err, ErrorMatches, "dummy environment not bootstrapped")
 
 	environ, err := environs.NewFromName("")
@@ -65,7 +65,7 @@
 	err = environ.Bootstrap(false)
 	c.Assert(err, IsNil)
 
-	conn, err = juju.NewConn("")
+	conn, err = juju.NewConnFromName("")
 	c.Assert(err, IsNil)
 	defer conn.Close()
 	c.Assert(conn.Environ, NotNil)
@@ -102,7 +102,7 @@
 	c.Assert(err, IsNil)
 	c.Assert(cfg.UnknownAttrs()["secret"], IsNil)
 
-	conn, err := juju.NewConnFromEnviron(env)
+	conn, err := juju.NewConn(env)
 	c.Assert(err, IsNil)
 	defer conn.Close()
 	// fetch a state connection via the conn, which will 

=== modified file 'juju/deploy_test.go'
--- juju/deploy_test.go	2012-09-03 14:09:44 +0000
+++ juju/deploy_test.go	2012-09-03 17:35:44 +0000
@@ -32,7 +32,7 @@
 	c.Assert(err, IsNil)
 	err = environ.Bootstrap(false)
 	c.Assert(err, IsNil)
-	s.conn, err = juju.NewConnFromEnviron(environ)
+	s.conn, err = juju.NewConn(environ)
 	c.Assert(err, IsNil)
 	s.repo = &charm.LocalRepository{Path: c.MkDir()}
 }

=== modified file 'juju/testing/conn.go'
--- juju/testing/conn.go	2012-09-03 14:09:44 +0000
+++ juju/testing/conn.go	2012-09-03 17:35:44 +0000
@@ -99,7 +99,7 @@
 	c.Assert(environ.Name(), Equals, "dummyenv")
 	c.Assert(environ.Bootstrap(false), IsNil)
 
-	conn, err := juju.NewConn("dummyenv")
+	conn, err := juju.NewConnFromName("dummyenv")
 	c.Assert(err, IsNil)
 	s.Conn = conn
 	s.State = conn.State

